/* mapview - map viewer for PalmOS
   Copyright (C) 2005  Edwin Steiner <edwin.steiner@gmx.net>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <PalmOS.h>
#include <string.h>
#include "maplist.h"
#include "memory.h"
#include "rsrc.h"
#include "debug.h"

mapview_maplist_t *
mapview_maplist_new(void)
{
        UInt16 cards;
        UInt16 cardno;
        UInt16 ndbs;
        UInt16 index;
        mapview_maplist_t *ml;
        mapview_maplist_item_t *item;
        LocalID dbid;
        UInt32 type;
        UInt32 creator;
        Char dbname[dmDBNameLength];
        Err err;

        ml = NEW(mapview_maplist_t);
        if (!ml)
                return NULL;

        ml->items = NULL;
        ml->n = 0;
        ml->_listitems = NULL;

        cards = MemNumCards();
        for (cardno=0; cardno<cards; ++cardno) {
        
                ndbs = DmNumDatabases(cardno);
                for (index=0; index<ndbs; ++index) {
                        dbid = DmGetDatabase(cardno,index);
                        if (!dbid)
                                continue;

                        err = DmDatabaseInfo(cardno,dbid,
                                        dbname,
                                        NULL, NULL, NULL, NULL, NULL, /* attr, version, crDate, modDate, bkupDate */
                                        NULL, NULL, NULL,             /* modnum, appinfo, sortinfo */
                                        &type, &creator);

                        if (err != errNone)
                                continue;

                        if (creator != MAPVIEW_CREATOR)
                                continue;

                        if (type != MAPVIEW_MAP_TYPE)
                                continue;

                        item = NEW(mapview_maplist_item_t);
                        item->cardno = cardno;
                        item->localid = dbid;
                        memcpy(item->name,dbname,dmDBNameLength);
                        item->next = ml->items;

                        ml->items = item;
                        ml->n++;
                }
        }
        
        return ml;
}

void
mapview_maplist_free(mapview_maplist_t *ml)
{
        if (!ml)
                return;

        if (ml->_listitems) {
                FREEARRAY(Char *,ml->n,ml->_listitems);
        }
        while (ml->items) {
                mapview_maplist_item_t *item = ml->items;
                ml->items = item->next;
                FREE(mapview_maplist_item_t,item);
        }
        FREE(mapview_maplist_t,ml);
}

UInt16 
mapview_maplist_n(mapview_maplist_t *ml)
{
        ASSERT(ml);
        return ml->n;
}

mapview_maplist_item_t *
mapview_maplist_nth_item(mapview_maplist_t *ml,Int32 index)
{
        mapview_maplist_item_t *item;
        
        ASSERT(ml);
        
        if (index < 0 || index >= ml->n)
                return NULL;

        item = ml->items;
        while (index) {
                item = item->next;
                index--;
        }
        return item;
}

void 
mapview_maplist_set_list_choices(mapview_maplist_t *ml,ListPtr lst)
{
        UInt16 i;
        mapview_maplist_item_t *item;
        
        ASSERT(ml);
        ASSERT(lst);

        if (!ml->_listitems) {
                ml->_listitems = NEWARRAY(Char *,ml->n);
                item = ml->items;
                for (i=0; i<ml->n; ++i, item=item->next) {
                        ml->_listitems[i] = item->name;
                }
        }

        LstSetListChoices(lst,ml->_listitems,ml->n);
        /* XXX check error */
}

/* vim: et sts=8 sw=8 ai
 */
