/* mapview - map viewer for PalmOS
   Copyright (C) 2005  Edwin Steiner <edwin.steiner@gmx.net>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef _VIEW_H_
#define _VIEW_H_

#include "global.h"
#include "map.h"

typedef struct mapview_view_t mapview_view_t;

struct mapview_view_t {
        mapview_map_t *         map;
        Int32                   x;
        Int32                   y;
        UInt16                  layer;
        UInt16                  coordsys;
        Int32                   viewx;
        Int32                   viewy;
        Int32                   viewsizex;
        Int32                   viewsizey;
        Int32                   stepsizex;
        Int32                   stepsizey;
        Int32                   xmin;
        Int32                   ymin;
        Int32                   xmax;
        Int32                   ymax;
};

mapview_view_t *mapview_view_new(mapview_map_t *map,UInt16 coordsys,
                                 int vx,int vy,int sx,int sy);
void mapview_view_free(mapview_view_t *view);

Int32 mapview_view_scale(mapview_view_t *view);
void mapview_view_get_center(mapview_view_t *view,Int32 *px,Int32 *py);
void mapview_view_get_visible_rect(mapview_view_t *view,Int32 *x,Int32 *y,Int32 *ex,Int32 *ey);

void mapview_view_screen_to_map(mapview_view_t *view,Int32 screenx,Int32 screeny,Int32 *x,Int32 *y);

void mapview_view_draw(mapview_view_t *view);
bool mapview_view_move_to(mapview_view_t *view,Int32 x,Int32 y);
bool mapview_view_move_center(mapview_view_t *view,Int32 x,Int32 y);
bool mapview_view_move_to_map_center(mapview_view_t *view);
bool mapview_view_move(mapview_view_t *view,Int32 dx,Int32 dy);
bool mapview_view_move_scaled(mapview_view_t *view,Int32 dx,Int32 dy);
bool mapview_view_down(mapview_view_t *view);
bool mapview_view_up(mapview_view_t *view);
bool mapview_view_switch_to_layer(mapview_view_t *view,int layer);

#endif

/* vim: et sts=8 sw=8 ai
 */
